Deployment: SKIL Deployment

Description Usage Arguments Examples

View source: R/deployments.R

Description

Deployments operate independently of workspaces to ensure that there are no accidental interruptions or mistakes in a production environment.

Usage

1
Deployment(skil = NULL, name = NULL, deployment_id = NULL)

Arguments

skil:

'Skil' server instance. If 'None', SKIL will load from config.

name:

string. Name for the deployment.

id:

Unique id for the deployment. If 'None', a unique id will be generated.ging.

Examples

1
2
3
4
5
6
7
8
## Not run: 
library(skilr)

# Creating a deployment
deployment <- Deployment()


## End(Not run)

SkymindIO/skilr documentation built on May 26, 2019, 1:42 a.m.