Experiment: SKIL Experiment

Description Usage Arguments Details Examples

View source: R/experiments.R

Description

Experiments in SKIL are useful for defining different model configurations, encapsulating training of models, and carrying out different data cleaning tasks.

Usage

1
2
3
Experiment(work_space = NULL, experiment_id = NULL,
  name = "experiment", description = "experiment", verbose = FALSE,
  skil_server = NULL, create = TRUE)

Arguments

work_space:

'WorkSpace' instance. If NULL a workspace will be created.

experiment_id:

integer. Unique id for workspace. If 'None', a unique id will be generated.

name:

string. Name for the experiment.

description:

string. Description for the experiment.

verbose:

boolean. If FALSE, api response will be printed.

skil_server:

Optional 'Skil' instance, used when create is false.

create:

boolean. If TRUE a new experiment will be created.

Details

Experiments have a one-to-one relationship with Notebooks and have their own storage mechanism for saving different model configurations when seeking a best candidate.

Examples

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
## Not run: 
library(skilr)

# Creating a SKIL experiment
skil <- Skil(host='localhost', port=9008, user_id='admin', password='admin')
ws   <- Workspace(skil, name='test_workspace')
exp  <- Experiment(ws, name='test_experiment')


## End(Not run)

SkymindIO/skilr documentation built on May 26, 2019, 1:42 a.m.