Model: SKIL Model wrapper for DL4J, Keras, TensorFlow and other...

Description Usage Arguments Examples

View source: R/models.R

Description

SKIL Model wrapper for DL4J, Keras, TensorFlow and other models SKIL has a robust model storage, serving, and import system for supporting major deep learning libraries. SKIL can be used for end-to-end training, configuration, and deployment of models or alternatively you can import models into SKIL.

Usage

1
2
Model(model = NULL, model_id = NULL, name = NULL, version = NULL,
  experiment = NULL, labels = "", verbose = FALSE, create = TRUE)

Arguments

model:

Model file path or model instance

model_id:

integer. Unique id for model. If NULL, a unique id will be generated.

name:

string. Name for the model.

version:

integer. Version of the model. Defaults to 1.

experiment:

'Experiment' instance. If NULL, an 'Experiment' object will be created internally.

labels:

string. Labels for this model

verbose:

boolean. If TRUE, prints api response.

create:

boolean. Internal. Do not use.

Examples

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
## Not run: 
library(skilr)

# Creating a SKIL experiment
skil  <- Skil(host='localhost', port=9008, user_id='admin', password='admin')
ws    <- Workspace(skil, name='test_workspace')
exp   <- Experiment(ws, name='test_experiment')
model <- Model(model="keras.h5", name="my_keras_model", experiment=exp)


## End(Not run)

SkymindIO/skilr documentation built on May 26, 2019, 1:42 a.m.