WorkSpace: SKIL Workspace

Description Usage Arguments Details Examples

View source: R/workspaces.R

Description

Workspaces are a collection of features that enable different tasks such as conducting experiments, training models, and test different dataset transforms.

Usage

1
2
WorkSpace(skil = NULL, name = NULL, labels = NULL, verbose = FALSE,
  create = TRUE)

Arguments

skil:

Skil server instance

name:

string. Name for the workspace.

labels:

string. Labels associated with the workspace, useful for searching (comma seperated).

verbose:

boolean. If True, api response will be printed.

create:

boolean. Internal, do not use.

Details

Workspaces are distinct from Deployments by operating as a space for non-production work.

Examples

1
2
3
4
5
6
7
8
9
## Not run: 
library(skilr)

# Creating a SKIL workspace
skil <- Skil(host='localhost', port=9008, user_id='admin', password='admin')
ws   <- Workspace(skil, name='test_workspace')


## End(Not run)

SkymindIO/skilr documentation built on May 26, 2019, 1:42 a.m.