Description Usage Arguments Examples
Deployments operate independently of workspaces to ensure that there are no accidental interruptions or mistakes in a production environment.
1 | Deployment(skil = NULL, name = NULL, deployment_id = NULL)
|
skil: |
'Skil' server instance. If 'None', SKIL will load from config. |
name: |
string. Name for the deployment. |
id: |
Unique id for the deployment. If 'None', a unique id will be generated.ging. |
1 2 3 4 5 6 7 8 | ## Not run:
library(skilr)
# Creating a deployment
deployment <- Deployment()
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.