Description Usage Arguments Details Examples
Experiments in SKIL are useful for defining different model configurations, encapsulating training of models, and carrying out different data cleaning tasks.
1 2 3 |
work_space: |
'WorkSpace' instance. If NULL a workspace will be created. |
experiment_id: |
integer. Unique id for workspace. If 'None', a unique id will be generated. |
name: |
string. Name for the experiment. |
description: |
string. Description for the experiment. |
verbose: |
boolean. If FALSE, api response will be printed. |
skil_server: |
Optional 'Skil' instance, used when create is false. |
create: |
boolean. If TRUE a new experiment will be created. |
Experiments have a one-to-one relationship with Notebooks and have their own storage mechanism for saving different model configurations when seeking a best candidate.
1 2 3 4 5 6 7 8 9 10 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.