Description Usage Arguments Details Examples
Workspaces are a collection of features that enable different tasks such as conducting experiments, training models, and test different dataset transforms.
1 2 |
skil: |
Skil server instance |
name: |
string. Name for the workspace. |
labels: |
string. Labels associated with the workspace, useful for searching (comma seperated). |
verbose: |
boolean. If True, api response will be printed. |
create: |
boolean. Internal, do not use. |
Workspaces are distinct from Deployments by operating as a space for non-production work.
1 2 3 4 5 6 7 8 9 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.